@@ -42,7 +42,7 @@ RSpec.configure do |config|
         "authors"  => {},
       },
       "url"         => "http://jekyllrb.com",
-      "gems"        => [
+      "plugins"     => [
         "jekyll-redirect-from",
         "jekyll-sitemap",
       ],
@@ -50,7 +50,7 @@ RSpec.configure do |config|
         "scope"  => { "path" => "" },
         "values" => { "layout" => "layout" },
       }]
-    ).backwards_compatibilize
+    )
   end
 
   def site
